@@ -1,11 +1,11 @@
-# Copyrights 2001-2008 by Mark Overmeer.
+# Copyrights 2001-2009 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.04.
+# Pod stripped from pm file by OODoc 1.06.
 
 package Mail::Box::File;
 use vars '$VERSION';
-$VERSION = '2.082';
+$VERSION = '2.093';
 
 use base 'Mail::Box';
 
@@ -36,7 +36,7 @@ my $default_folder_dir = exists $ENV{HOME} ? $ENV{HOME} . '/Mail' : '.';
 
 sub _default_body_type($$)
 {   my $size = shift->guessBodySize || 0;
-    'Mail::Message::Body::'.($size > 10000 ? 'File' : 'Lines');
+    'Mail::Message::Body::'.($size > 100000 ? 'File' : 'Lines');
 }
 
 sub init($)
@@ -47,9 +47,9 @@ sub init($)
 
     return unless defined $self->SUPER::init($args);
 
-    my $class = ref $self;
+    my $class    = ref $self;
 
-    my $filename         = $self->{MBF_filename}
+    my $filename = $self->{MBF_filename}
        = $class->folderToFilename
            ( $self->name
            , $self->folderdir
@@ -335,7 +335,7 @@ sub writeMessages($)
         return;
     }
 
-    $self->parser->restart;
+#   $self->parser->restart;
     $self;
 }
 
@@ -351,7 +351,7 @@ sub _write_new($)
     $new->close or return 0;
 
     $self->log(PROGRESS =>
-                  "Wrote new folder $self with ".@{$args->{messages}}."msgs.");
+        "Wrote new folder $self with ".@{$args->{messages}}."msgs.");
     1;
 }
 
@@ -381,25 +381,25 @@ sub _write_replace($)
             $message->moveLocation($newbegin - $oldbegin)
                if defined $oldbegin;
             $reprint++;
+            next;
         }
-        else
-        {   my ($begin, $end) = $message->fileLocation;
-            my $need = $end-$begin;
 
-            $old->seek($begin, 0);
-            my $whole;
-            my $size = $old->read($whole, $need);
+        my ($begin, $end) = $message->fileLocation;
+        my $need = $end-$begin;
 
-            $self->log(ERROR => "File too short to get write message "
-                                . $message->seqnr. " ($size, $need)")
-               unless $size == $need;
+        $old->seek($begin, 0);
+        my $whole;
+        my $size = $old->read($whole, $need);
 
-            $new->print($whole);
-            $new->print("\n");
+        $self->log(ERROR => "File too short to get write message "
+                            . $message->seqnr. " ($size, $need)")
+           unless $size == $need;
 
-            $message->moveLocation($newbegin - $oldbegin);
-            $kept++;
-        }
+        $new->print($whole);
+        $new->print("\n");
+
+        $message->moveLocation($newbegin - $oldbegin);
+        $kept++;
     }
 
     my $ok = $new->close;
