@@ -1,13 +1,13 @@
-# Copyrights 2001-2008 by Mark Overmeer.
+# Copyrights 2001-2009 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.05.
+# Pod stripped from pm file by OODoc 1.06.
 
 use strict;
 
 package Mail::Box::Locker::POSIX;
 use vars '$VERSION';
-$VERSION = '2.086';
+$VERSION = '2.093';
 
 use base 'Mail::Box::Locker';
 
@@ -16,11 +16,17 @@ use IO::File;
 use Errno   qw/EAGAIN/;
 
 
+sub init($)
+{   my ($self, $args) = @_;
+    $args->{file} = $args->{posix_file} if $args->{posix_file};
+    $self->SUPER::init($args);
+}
+
 sub name() {'POSIX'}
 
 sub _try_lock($)
 {   my ($self, $file) = @_;
-    $? = fcntl($file, F_SETLK, pack('s @256', F_WRLCK)) || 0;
+    $? = fcntl($file, F_SETLK, pack('s @256', F_WRLCK)) || ($!+0);
     $?==0;
 }
 
@@ -60,7 +66,7 @@ sub lock()
             return 1;
         }
 
-        if($? != EAGAIN)
+        unless($!==EAGAIN)
         {   $self->log(ERROR =>
             "Will never get a POSIX lock on $filename for $self->{MBL_folder}: $!");
             last;
@@ -85,10 +91,9 @@ sub isLocked()
         return 0;
     }
 
-    $self->_try_lock($file) or return 0;
+    $self->_try_lock($file)==0 or return 0;
     $self->_unlock($file);
     $file->close;
-
     1;
 }
 
