@@ -1,13 +1,13 @@
-# Copyrights 2001-2008 by Mark Overmeer.
+# Copyrights 2001-2009 by Mark Overmeer.
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.04.
+# Pod stripped from pm file by OODoc 1.06.
 use strict;
 use warnings;
 
 package Mail::Box::Parser::Perl;
 use vars '$VERSION';
-$VERSION = '2.082';
+$VERSION = '2.093';
 
 use base 'Mail::Box::Parser';
 
@@ -52,8 +52,7 @@ sub readHeader()
 {   my $self  = shift;
     my $file  = $self->{MBPP_file};
 
-    my $start = $file->tell;
-    my @ret   = ($start, undef);
+    my @ret   = ($file->tell, undef);
     my $line  = $file->getline;
 
   LINE:
@@ -264,25 +263,17 @@ sub bodyDelayed(;$$)
 
 sub openFile($)
 {   my ($self, $args) = @_;
-    my $fh = $args->{file} || IO::File->new($args->{filename}, $args->{mode});
+    my $mode = $args->{mode} or die "mode required";
+    my $fh = $args->{file} || IO::File->new($args->{filename}, $mode);
 
     return unless $fh;
     $self->{MBPP_file}       = $fh;
 
-    binmode $fh, ':raw'
+    $fh->binmode(':raw')
        if ref($fh) eq 'GLOB' || $fh->can('BINMODE');
 
     $self->{MBPP_separators} = [];
 
-    # Prepare the first line.
-    $self->{MBPP_start_line} = 0;
-
-    my $line  = $fh->getline || return $self;
-
-    $line     =~ s/[\012\015]+$/\n/;
-    $self->{MBP_linesep}     = $1;
-    $fh->seek(0, 0);
-
 #   binmode $fh, ':crlf' if $] < 5.007;  # problem with perlIO
     $self;
 }
