@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Message::Field::Address;
 use vars '$VERSION';
-$VERSION = '2.090';
+$VERSION = '2.093';
 
 use base 'Mail::Identity';
 
@@ -28,11 +28,10 @@ sub coerce($@)
 {  my ($class, $addr, %args) = @_;
    return () unless defined $addr;
 
-   return $class->parse($addr) unless ref $addr;
+   ref $addr or return $class->parse($addr);
+   $addr->isa($class) and return $addr;
 
-   return $addr if $addr->isa($class);
-
-   my $from = $class->from($addr);
+   my $from = $class->from($addr, %args);
 
    Mail::Reporter->log(ERROR => "Cannot coerce a ".ref($addr)." into a $class"),
       return () unless defined $from;
