@@ -7,7 +7,7 @@ use warnings;
 
 package Mail::Message::Head::Complete;
 use vars '$VERSION';
-$VERSION = '2.090';
+$VERSION = '2.093';
 
 use base 'Mail::Message::Head';
 
@@ -131,7 +131,7 @@ sub count($)
 
 
 sub names() {shift->knownNames}
- 
+
 #------------------------------------------
 
 
@@ -215,7 +215,7 @@ sub reset($@)
     $self->addOrderedFields(@fields);
     $self;
 }
- 
+
 #------------------------------------------
 
 
@@ -254,7 +254,7 @@ sub removeFields(@)
 {   my $self = shift;
     (bless $self, 'Mail::Message::Head::Partial')->removeFields(@_);
 }
-   
+
 #------------------------------------------
 
 
@@ -334,7 +334,7 @@ sub printUndisclosed($)
 
 #------------------------------------------
 
-                                                                                
+
 sub printSelected($@)
 {   my ($self, $fh) = (shift, shift);
 
@@ -352,7 +352,7 @@ sub printSelected($@)
         elsif(ref $fh eq 'GLOB') { print $fh "\n" }
         else                     { $fh->print("\n") }
     }
-                                                                                
+
     $self;
 }
 
@@ -520,11 +520,10 @@ sub guessBodySize()
 
 sub createFromLine()
 {   my $self   = shift;
-
-    my $from   = $self->get('from') || '';
-    my $stamp  = $self->timestamp;
-    my $sender = $from =~ m/(\<.*?\>)/ ? $1 : 'unknown';
-    "From $sender ".(gmtime $stamp)."\n";
+    my $sender = $self->message->sender;
+    my $stamp  = $self->recvstamp || $self->timestamp || time;
+    my $addr   = defined $sender ? $sender->address : 'unknown';
+    "From $addr ".(gmtime $stamp)."\n"
 }
 
 #------------------------------------------
